import React, { useState, useEffect, useRef} from 'react';
import axios from 'axios';
import '../styles/App.css';
import TankList from './items/Tank/TankList';
import './AddTank.css';

const hostURL = "http://localhost:8080";
const host = hostURL + "/api/1.0/";

const AddTank = () => {
    const [tankItems, setTankItems] = useState([]);

    //для создания нового танка
    const [tankName, setTankName] = useState({tankName: ''});

    const [tankCost, setTankCost] = useState({tankCost: ''});

    const [nationItems, setNationItems] = useState([]);

    const [levelItems, setLevelItems] = useState([]);

    //храним выбранные нацию и уровень для нового танка
    const [chooiceNation, setChooiceNation] = useState();
    const [chooiceLevel, setChooiceLevel] = useState();

    const [fileByte, setFileByte] = useState(null);
    const inputRef = useRef();

    const getTokenForHeader = function () {
        return "Bearer " + localStorage.getItem("token");
    }

    //загрузка всеГо необходимого при старте
    useEffect(() => {
        getTanks();
        getLevels();
        getNations();
    }, [])

    //загрузка всех имеющихся танков, а также уровней и наций при старте
    const getTanks = async function () {
        const requestParams = {
            method: "GET",
            headers: {
                "Authorization": getTokenForHeader(),
            }
        };
        const requestUrl = host + `tank/`;
        const response = await fetch(requestUrl, requestParams);
        const data = await response.json();
        console.log(data);
        setTankItems(data);
    }

    const getNations = async function () {
        const requestParams = {
            method: "GET",
            headers: {
                "Authorization": getTokenForHeader(),
            }
        };
        const requestUrl = host + `nation/getNations`;
        const response = await fetch(requestUrl, requestParams);
        const data = await response.json();
        console.log(data);
        setNationItems(data);
    }

    //загрузка всех имеющихся уровней при старте
    const getLevels = async function () {
        const requestParams = {
            method: "GET",
            headers: {
                "Authorization": getTokenForHeader(),
            }
        };
        const requestUrl = host + `level/getLevels`;
        const response = await fetch(requestUrl, requestParams);
        const data = await response.json();
        console.log(data);
        setLevelItems(data);
    }

    //обновить список танков
    function CheckArray(){
        getTanks();
        getLevels();
        getNations();
    }

    //добавление нового танка
    async function addNewTank(){
        console.log(tankName);
        console.log(tankCost);
        console.log(chooiceNation);
        console.log(chooiceLevel);

        const requestParams = {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
                "Authorization": getTokenForHeader(),
            }
        };
        const requestUrl = host + `tank/create/?firstName=${tankName.tankName}&nationId=${chooiceNation}&levelId=${chooiceLevel}&cost=${tankCost.tankCost}`;
        const response = await fetch(requestUrl, requestParams);
        CheckArray();
        setTankCost({tankCost: ''});
        setTankName({tankName: ''});
    }

    const getChoiceNation = (newId) => {
        setChooiceNation(nationItems[newId - 1].id);
    }

    const getChoiceLevel = (newId) => {
        setChooiceLevel(levelItems[newId - 1].id);
    }

    //добавили условную отрисовку
    return(
        <div>
            <div className="Group_create_level">
                <h1>Генератор танков</h1>
                <div>
                    <p style={{fontWeight: "900"}}>
                        Выберите нацию:
                        <select
                            onChange={(event) => getChoiceNation(event.target.selectedIndex)}
                        >
                            <option selected>Выберите нацию</option>
                            {nationItems.map((nationItem) =>
                                <option
                                    value={nationItem.nation}
                                    key={nationItem.id}
                                >
                                    {nationItem.nation} 
                                </option>
                            )}
                        </select>
                    </p>
                    <p style={{fontWeight: "900"}}>
                        Выберите уровень:
                        <select style={{marginTop: "10px"}}
                            onChange={(event) => getChoiceLevel(event.target.selectedIndex)}
                        >
                            <option selected>Выберите уровень</option>
                            {levelItems.map((levelItem) =>
                                <option
                                    value={levelItem.level} 
                                    key={levelItem.id}
                                >
                                    {levelItem.level} 
                                </option>
                            )}
                        </select>
                    </p>
                    <p style={{fontWeight: "900"}}>
                        Введите название:
                        <input
                            className="add-tank-input"
                            value={tankName.tankName}
                            onChange={e => setTankName({tankName: e.target.value})}
                        />
                    </p>
                    <p style={{fontWeight: "900"}}>
                        Введите стоимость:
                        <input
                            className="add-tank-input"
                            value={tankCost.tankCost}
                            onChange={e => setTankCost({tankCost: e.target.value})}
                        />
                    </p>
                </div>
                <div>
                    <button className='add-level-button'
                        onClick={addNewTank}
                    >
                        Создать танк
                    </button>
                    <button className='add-level-button'
                         onClick={CheckArray}
                    >
                        Вывести все танки
                    </button>
                </div>
            </div>
            <div className="Card_list">
                {tankItems.length !== 0
                    ? 
                    <TankList tankItems={tankItems}
                    />
                    : 
                    <h1 style={{textAlign: 'center'}}>В БД отсутствуют какие-либо танки!</h1>
                }
            </div>
        </div>
    );
}

export default AddTank
